from setuptools import setup, find_packages

setup(
    name="a-datas-stock",
    version="0.0.1",
    author="A-DATAS Team",
    author_email="team@a-datas.com",
    description="A股数据工具包（占位包）",
    long_description="A-DATAS股票数据工具包，提供A股日线数据解析功能",
    url="https://github.com/a-datas/a-datas-stock",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Financial and Insurance Industry",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    python_requires=">=3.8",
)